==> ejc-assistrmat-impl-3.0.0-20220323.082804-14-sources.jar: com/ejianc/business/assist/rmat/bean/ChangeClauseEntity.java <==
package com.ejianc.business.assist.rmat.bean;

import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;

/**
 * 周转材租赁合同-合同条款变更表
 * 
 * @author generator
 * 
 */
 @TableName("ejc_assistrmat_contract_change_clause")
public class ChangeClauseEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;
    
    @TableField(value="change_id")
    private Long changeId; // 变更主键
    @TableField(value="change_type")
    private String changeType; // 变更类型
    @TableField(value="contract_id")
    private Long contractId; // 合同id
    @TableField(value="source_id")
    private Long sourceId; // 来源数据Id(参照数据id)
    @TableField(value="source_bid")
    private Long sourceBid; // 来源子表主键(合同子表id)
    @TableField(value="source_type")
    private String sourceType; // 来源类型：0-直接新增，1-定标结果带入
    @TableField(value="clause_name_id")
    private Long clauseNameId; // 合同条款名称Id
    @TableField(value="clause_name")
    private String clauseName; // 合同条款名称
    @TableField(value="clause_content")
    private String clauseContent; // 合同条款内容
    
    
    

    public Long getChangeId() {
        return changeId;
    }

    public void setChangeId(Long changeId) {
        this.changeId = changeId;
    }
    public String getChangeType() {
        return changeType;
    }

    public void setChangeType(String changeType) {
        this.changeType = changeType;
    }
    public Long getContractId() {
        return contractId;
    }

    public void setContractId(Long contractId) {
        this.contractId = contractId;
    }
    public Long getSourceId() {
        return sourceId;
    }

    public void setSourceId(Long sourceId) {
        this.sourceId = sourceId;
    }
    public Long getSourceBid() {
        return sourceBid;
    }

    public void setSourceBid(Long sourceBid) {
        this.sourceBid = sourceBid;
    }
    public String getSourceType() {
        return sourceType;
    }

    public void setSourceType(String sourceType) {
        this.sourceType = sourceType;
    }
    public Long getClauseNameId() {
        return clauseNameId;
    }

    public void setClauseNameId(Long clauseNameId) {
        this.clauseNameId = clauseNameId;
    }
    public String getClauseName() {
        return clauseName;
    }

    public void setClauseName(String clauseName) {
        this.clauseName = clauseName;
    }
    public String getClauseContent() {
        return clauseContent;
    }

    public void setClauseContent(String clauseContent) {
        this.clauseContent = clauseContent;
    }
    
}

==> ejc-assistrmat-impl-3.0.0-20221111.025345-289-sources.jar: com/ejianc/business/assist/rmat/bean/ChangeClauseEntity.java <==
package com.ejianc.business.assist.rmat.bean;

import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;

/**
 * 周转材租赁合同-合同条款变更表
 * 
 * @author generator
 * 
 */
 @TableName("ejc_assistrmat_contract_change_clause")
public class ChangeClauseEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;
    
    @TableField(value="change_id")
    private Long changeId; // 变更主键
    @TableField(value="change_type")
    private String changeType; // 变更类型
    @TableField(value="contract_id")
    private Long contractId; // 合同id
    @TableField(value="source_id")
    private Long sourceId; // 来源数据Id(参照数据id)
    @TableField(value="source_bid")
    private Long sourceBid; // 来源子表主键(合同子表id)
    @TableField(value="source_type")
    private String sourceType; // 来源类型：0-直接新增，1-定标结果带入
    @TableField(value="clause_name_id")
    private Long clauseNameId; // 合同条款名称Id
    @TableField(value="clause_name")
    private String clauseName; // 合同条款名称
    @TableField(value="clause_content")
    private String clauseContent; // 合同条款内容
    @TableField(value="necessary_status")
    private Integer necessaryStatus; // 是否必填：0-否，1-是
    
    

    public Long getChangeId() {
        return changeId;
    }

    public void setChangeId(Long changeId) {
        this.changeId = changeId;
    }
    public String getChangeType() {
        return changeType;
    }

    public void setChangeType(String changeType) {
        this.changeType = changeType;
    }
    public Long getContractId() {
        return contractId;
    }

    public void setContractId(Long contractId) {
        this.contractId = contractId;
    }
    public Long getSourceId() {
        return sourceId;
    }

    public void setSourceId(Long sourceId) {
        this.sourceId = sourceId;
    }
    public Long getSourceBid() {
        return sourceBid;
    }

    public void setSourceBid(Long sourceBid) {
        this.sourceBid = sourceBid;
    }
    public String getSourceType() {
        return sourceType;
    }

    public void setSourceType(String sourceType) {
        this.sourceType = sourceType;
    }
    public Long getClauseNameId() {
        return clauseNameId;
    }

    public void setClauseNameId(Long clauseNameId) {
        this.clauseNameId = clauseNameId;
    }
    public String getClauseName() {
        return clauseName;
    }

    public void setClauseName(String clauseName) {
        this.clauseName = clauseName;
    }
    public String getClauseContent() {
        return clauseContent;
    }

    public void setClauseContent(String clauseContent) {
        this.clauseContent = clauseContent;
    }

    public Integer getNecessaryStatus() {
        return necessaryStatus;
    }

    public void setNecessaryStatus(Integer necessaryStatus) {
        this.necessaryStatus = necessaryStatus;
    }

}
